package wdbpress.java17.examples.httpclient;

import java.io.*;
import java.net.*;
import java.net.http.*;
import java.time.*;

import com.google.gson.*;


public class Shutoko{

  public static final URI JSON_URI = URI.create("https://data.corona.go.jp/converted-json/transportation_facilities_road.json");

  private static void processJSON(InputStream in){
    try(var reader = new InputStreamReader(in)){
      var parser = new JsonStreamParser(reader);
      if(parser.hasNext()){
        var array = parser.next().getAsJsonArray();
        var itr = array.iterator();

        while(itr.hasNext()){
          var obj = itr.next().getAsJsonObject();
          var dataName = obj.getAsJsonPrimitive("dataName").getAsString();
          if(dataName.equals("首都高速")){
            var date = obj.getAsJsonPrimitive("date").getAsString();
            var all = obj.getAsJsonPrimitive("all").getAsInt();
            System.out.println(date + " " + dataName + ": " + Integer.toString(all));
            return;
          }
        }

      }
    }
    catch(IOException e){
      throw new UncheckedIOException(e);
    }
  }

  public static void main(String[] args) throws Exception{
    var client = HttpClient.newBuilder()
                           .version(HttpClient.Version.HTTP_2)
                           .followRedirects(HttpClient.Redirect.NORMAL)
                           .connectTimeout(Duration.ofSeconds(3))
                           .build();
    var request = HttpRequest.newBuilder()
                             .uri(JSON_URI)
                             .timeout(Duration.ofSeconds(5))
                             .GET()
                             .setHeader("Accept", "application/json")
                             .build();

    var future = client.sendAsync(request, HttpResponse.BodyHandlers.ofInputStream())
                       .thenApply(HttpResponse::body)
                       .thenAccept(Shutoko::processJSON);

    System.out.println("Processing...");

    future.join();
  }

}
